@@ -7,7 +7,7 @@ class AmpMixin:
 
     @property
     def amp_template(self):
-        name, ext = os.path.splitext(self.template)
+        name, ext = os.path.splitext(super().get_template({}))
         return name + '_amp' + ext
 
     def get_template(self, request):
