@@ -132,12 +132,12 @@ class EntryBlock(Mocker, blocks.StructBlock):
     )
     svg_bg_position = BackgroundPositionChoiceBlock(
         required=False,
-        default=constants.BACKROUND_POSITION_CENTER
+        default=constants.BACKROUND_POSITION_CENTER,
     )
-    theme = ThemeChoiceBlock(required=False)
     container = ContainerChoiceBlock(required=False)
     padding_top = blocks.BooleanBlock(default=True, required=False)
     padding_bottom = blocks.BooleanBlock(default=True, required=False)
+    theme = ThemeChoiceBlock(required=False)
 
     def get_template(self, context=None):
         if amp_mode_active():
