@@ -1,6 +1,7 @@
 from wagtail.core import blocks
 
 from webspace.cms import constants
+from webspace.cms.blocks.choice import ThemeChoiceBlock
 from webspace.cms.blocks.common import \
     SvgWithSizeBlock, \
     TextBlock, \
@@ -29,6 +30,7 @@ class CustomCard(blocks.StructBlock):
 
 class CardsEntry(EntryBlock):
     amp_scripts = ['carousel']
+    theme_reverse = ThemeChoiceBlock(required=False)
     carousel = blocks.BooleanBlock(required=False)
     cards = blocks.StreamBlock(
         [
