@@ -5,7 +5,7 @@ from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
 from django.utils.translation import gettext as _
 
-from wagtail.admin.edit_handlers import (InlinePanel, FieldPanel)
+from wagtail.admin.edit_handlers import (InlinePanel, FieldPanel, MultiFieldPanel)
 from wagtail.contrib.forms.models import FormBuilder, WagtailAdminFormPageForm
 from wagtail.contrib.forms.models import AbstractFormField
 from wagtail.core.models import Page
@@ -144,6 +144,13 @@ class AForm(ClusterableModel):
         blank=True,
         features=settings.RICH_TEXT_FEATURES
     )
+    text_align = models.CharField(
+        choices=constants.ALIGN_TEXT_CHOICES,
+        default=constants.ALIGN_TEXT_LEFT,
+        max_length=100,
+        help_text="Permet de changer le theme"
+    )
+    inline = models.BooleanField(default=False)
 
     button_text = models.CharField(
         verbose_name="Bouton text",
@@ -177,11 +184,19 @@ class AForm(ClusterableModel):
 
     settings_panel = [
         FieldPanel("help_text"),
-        FieldPanel("text"),
-        PageChooserPanel("redirection_page"),
-        FieldPanel('redirection_url'),
-        FieldPanel("button_text"),
-        FieldPanel('button_theme'),
+        MultiFieldPanel([
+            FieldPanel("text"),
+            FieldPanel("text_align"),
+        ], "Text du haut"),
+        MultiFieldPanel([
+            FieldPanel("button_text"),
+            FieldPanel('button_theme'),
+        ], "Bouton"),
+        MultiFieldPanel([
+            PageChooserPanel("redirection_page"),
+            FieldPanel('redirection_url'),
+        ], "Redirection"),
+        FieldPanel("inline"),
     ]
 
     submissions_panel = [
